plot_context: A helper function to plot mutational contexts, which are...

Description Usage Arguments

View source: R/plot_signatures.R

Description

A helper function to plot mutational contexts, which are generally counts (in contrast to signatures, which are generally proportions).

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
plot_context(
  x,
  label = "Signature",
  title = "",
  xlabel = "Motif Length or Count",
  ylabel = "Count",
  usePercent = FALSE,
  ylimits = NULL,
  countsAsProportions = FALSE,
  separatePlots = FALSE,
  contextType = contextType
)

Arguments

x

A TidySig dataframe/tibble

label

The right-side (i.e., facet) label. Usually "Signature" or "Sample" or a sample ID.

title

A title for the plot

xlabel

An x-axis label

ylabel

A y-axis label

usePercent

Use percent scales (rather than counts)

ylimits

Use custom ylimits (useful for normalizing the views of multiple signatures). Takes a numeric vector length-two.

countsAsProportions

Use proportions, rather than raw counts.

separatePlots

Produce separate plots, one per Signature

contextType

An argument for determining the context, either ID83 or SBS96


edawson/tidysig documentation built on May 2, 2020, 5:33 a.m.