Description Usage Arguments Value
View source: R/plot_signatures.R
Plot an ID83 signature ro series of signatures
1 2 3 4 5 6 7 8 9 10 11 12 |
x |
A TidySig dataframe/tibble |
label |
The right-side (i.e., facet) label. Usually "Signature" or "Sample" or a sample ID. |
title |
A title for the plot |
xlabel |
An x-axis label |
ylabel |
A y-axis label |
usePercent |
Use percent scales (rather than counts) |
ylimits |
Use custom ylimits (useful for normalizing the views of multiple signatures). Takes a numeric vector length-two OR a string "smart" to indicate that consistent y-limits should be automatically fit from the values in x. |
countsAsProportions |
Convert the input data (in counts) to per-signature proportions |
separatePlots |
If true, return a vector of plots, one for each signature, rather than one plot with a facet for each signature. |
contextType |
An argument for determining the context, generally "SBS96" or "ID83". The default, "auto", will attempt to determine the context automatically based on the columns of the x. |
a ggplot2 object, unless separatePlot = True, in which case a list of ggplot objects is returned.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.